@@ -158,12 +158,13 @@ class Worker:
         # that might have been created by other workers.
         try:
             self.docker.networks.prune(filters={"until": "1h"})
-        except (docker.errors.APIError, requests.exceptions.ReadTimeout) as e:
+        except (docker.errors.APIError, requests.exceptions.RequestException) as e:
             # docker.errors.APIError is raised when a prune is already running:
             # https://github.com/codalab/codalab-worksheets/issues/2635
             # docker.errors.APIError: 409 Client Error: Conflict ("a prune operation is already running").
-            # requests.exceptions.ReadTimeout is raised when the request to the Docker socket times out.
-            # https://github.com/docker/docker-py/issues/2266
+            # Any number of requests.exceptions.RequestException s are raised when the request to
+            # the Docker socket times out or otherwise fails.
+            # For example: https://github.com/docker/docker-py/issues/2266
             # Since pruning is a relatively non-essential routine (i.e., it's ok if pruning fails
             # on one or two iterations), we just ignore this issue.
             logger.warning("Cannot prune docker networks: %s", str(e))
@@ -553,6 +554,8 @@ class Worker:
                 remote=self.id,
                 exitcode=run_state.exitcode,
                 failure_message=run_state.failure_message,
+                cpu_usage=run_state.cpu_usage,
+                memory_limit=run_state.memory_limit,
             )
             for run_state in self.runs.values()
         ]
@@ -641,6 +644,8 @@ class Worker:
                 finished=False,
                 finalized=False,
                 is_restaged=False,
+                cpu_usage=0.0,
+                memory_limit=0,
             )
             # Increment the number of runs that have been successfully started on this worker
             self.num_runs += 1
