@@ -103,6 +103,8 @@ RunState = namedtuple(
         'finished',  # bool
         'finalized',  # bool
         'is_restaged',  # bool
+        'cpu_usage',  # float
+        'memory_limit',  # int
     ],
 )
 
@@ -406,7 +408,13 @@ class RunStateMachine(StateTransitioner):
                 finished=finished, exitcode=exitcode, failure_message=failure_msg
             )
 
-        def check_resource_utilization(run_state):
+        def check_resource_utilization(run_state: RunState):
+            cpu_usage, memory_limit = docker_utils.get_container_stats_with_docker_stats(
+                run_state.container
+            )
+            run_state = run_state._replace(cpu_usage=cpu_usage)
+            run_state = run_state._replace(memory_limit=memory_limit)
+
             kill_messages = []
 
             run_stats = docker_utils.get_container_stats(run_state.container)
